@@ -6,17 +6,17 @@
 class wxAuiManagerDupe {
     public:
         wxAuiManagerDupe(wxWindow* /*managed_wnd*/ = NULL, unsigned int /*flags*/ = 0 ) {}
-        bool AddPane(wxWindow* /*window*/, int /*direction*/ = wxLEFT, const wxString& /*caption */= wxEmptyString) { return false; }
-        bool DetachPane(wxWindow* /*window*/) { return false; }
-        void UnInit() {}
-        wxString SavePerspective() { return wxEmptyString; }
-        bool LoadPerspective(const wxString& /*perspective*/, bool /*update*/ = true) { return false; }
+        bool AddPane(wxWindow* /*window*/, int /*direction*/ = wxLEFT, const wxString& /*caption */= wxEmptyString) const { return false; }
+        bool DetachPane(wxWindow* /*window*/) const { return false; }
+        void UnInit() const {}
+        wxString SavePerspective() const { return wxEmptyString; }
+        bool LoadPerspective(const wxString& /*perspective*/, bool /*update*/ = true) const { return false; }
 };
 
 class AuiManagerContainer
 {
   public:
-    AuiManagerContainer() {}
+    AuiManagerContainer() : manager(NULL) {}
 
     typedef wxAuiManager
         ManagerType;
