@@ -212,10 +212,18 @@ User& Battle::OnUserAdded( User& user )
     {
         if ( CheckBan( user ) ) return user;
 
-		if ( ( &user != &GetMe() ) && !user.BattleStatus().IsBot() && ( m_opts.rankneeded > UserStatus::RANK_1 ) && ( user.GetStatus().rank < m_opts.rankneeded ) && !user.BattleStatus().spectator )
+		if ( ( &user != &GetMe() ) && !user.BattleStatus().IsBot() && ( m_opts.rankneeded != UserStatus::RANK_1 ) && !user.BattleStatus().spectator )
         {
-					DoAction( _T("Rank limit autospec: ") + user.GetNick() );
-					ForceSpectator( user, true );
+			 if ( m_opts.rankneeded > UserStatus::RANK_1 && user.GetStatus().rank < m_opts.rankneeded )
+			 {
+				DoAction( _T("Rank limit autospec: ") + user.GetNick() );
+				ForceSpectator( user, true );
+			 }
+			 else if ( m_opts.rankneeded < UserStatus::RANK_1 && user.GetStatus().rank > ( -m_opts.rankneeded - 1 ) )
+			 {
+				 DoAction( _T("Rank limit autospec: ") + user.GetNick() );
+				 ForceSpectator( user, true );
+			 }
         }
 
         m_ah.OnUserAdded( user );
@@ -229,10 +237,18 @@ void Battle::OnUserBattleStatusUpdated( User &user, UserBattleStatus status )
 {
     if ( IsFounderMe() )
     {
-			if ( ( &user != &GetMe() ) && !status.IsBot() && ( m_opts.rankneeded > UserStatus::RANK_1 ) && ( user.GetStatus().rank < m_opts.rankneeded ) && !status.spectator )
+			if ( ( &user != &GetMe() ) && !status.IsBot() && ( m_opts.rankneeded != UserStatus::RANK_1 ) && !status.spectator )
 			{
+				if ( m_opts.rankneeded > UserStatus::RANK_1 && user.GetStatus().rank < m_opts.rankneeded )
+				{
 					DoAction( _T("Rank limit autospec: ") + user.GetNick() );
 					ForceSpectator( user, true );
+				}
+				else if ( m_opts.rankneeded < UserStatus::RANK_1 && user.GetStatus().rank > ( -m_opts.rankneeded - 1 ) )
+				{
+					DoAction( _T("Rank limit autospec: ") + user.GetNick() );
+					ForceSpectator( user, true );
+				}
 			}
 			UserBattleStatus previousstatus = user.BattleStatus();
 			if ( m_opts.lockexternalbalancechanges )
@@ -589,20 +605,24 @@ void Battle::StartHostedBattle()
 			}
 			if ( IsProxy() )
 			{
-				wxString hostscript = spring().WriteScriptTxt( *this );
-				try
+				if ( UserExists( GetProxy() ) && !GetUser(GetProxy()).Status().in_game )
 				{
-					wxString path = sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("relayhost_script.txt");
-					if ( !wxFile::Access( path, wxFile::write ) ) {
-							wxLogError( _T("Access denied to script.txt.") );
-					}
+					// DON'T set m_generating_script here, it will trick the script generating code to think we're the host
+					wxString hostscript = spring().WriteScriptTxt( *this );
+					try
+					{
+						wxString path = sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("relayhost_script.txt");
+						if ( !wxFile::Access( path, wxFile::write ) ) {
+								wxLogError( _T("Access denied to script.txt.") );
+						}
 
-					wxFile f( path, wxFile::write );
-					f.Write( hostscript );
-					f.Close();
+						wxFile f( path, wxFile::write );
+						f.Write( hostscript );
+						f.Close();
 
-				} catch (...) {}
-				m_serv.SendScriptToProxy( hostscript );
+					} catch (...) {}
+					m_serv.SendScriptToProxy( hostscript );
+				}
 			}
 			if( IsFounderMe() && GetAutoLockOnStart() )
 			{
@@ -612,6 +632,10 @@ void Battle::StartHostedBattle()
 			sett().SetLastHostMap( GetServer().GetCurrentBattle()->GetHostMapName() );
 			sett().SaveSettings();
 			if ( !IsProxy() ) GetServer().StartHostedBattle();
+			else if ( UserExists( GetProxy() ) && GetUser(GetProxy()).Status().in_game ) // relayhost is already ingame, let's try to join it
+			{
+				StartSpring();
+			}
 		}
 	}
 }
@@ -622,7 +646,10 @@ void Battle::StartSpring()
 	{
 		GetMe().BattleStatus().ready = false;
 		SendMyBattleStatus();
+		// set m_generating_script, this will make the script.txt writer realize we're just clients even if using a relayhost
+		m_generating_script = true;
 		GetMe().Status().in_game = spring().Run( *this );
+		m_generating_script = false;
 		GetMe().SendMyUserStatus();
 	}
 	ui().OnBattleStarted( *this );
@@ -727,7 +754,7 @@ struct Alliance
     std::vector<User *>players;
     float ranksum;
     int allynum;
-    Alliance(): ranksum(0) {}
+    Alliance(): ranksum(0), allynum(-1) {}
     Alliance(int i): ranksum(0), allynum(i) {}
     void AddPlayer( User *player )
     {
@@ -752,7 +779,7 @@ struct ControlTeam
     std::vector<User*> players;
     float ranksum;
     int teamnum;
-    ControlTeam(): ranksum(0) {}
+    ControlTeam(): ranksum(0), teamnum(-1) {}
     ControlTeam( int i ): ranksum(0), teamnum(i) {}
     void AddPlayer( User *player )
     {
