@@ -78,8 +78,7 @@ BattleListCtrl::BattleListCtrl( wxWindow* parent )
 
 BattleListCtrl::~BattleListCtrl()
 {
-    if ( m_popup )
-        delete m_popup;
+    delete m_popup;
 }
 
 wxString BattleListCtrl::GetItemText(long item, long column) const
@@ -133,7 +132,7 @@ int BattleListCtrl::GetItemColumnImage(long item, long column) const
         	}catch(...){}
 					break;
         }
-        case 2: return icons().GetRankIcon( battle.GetRankNeeded(), false );
+		case 2: return icons().GetRankLimitIcon( battle.GetRankNeeded(), false );
         case 4: return battle.MapExists() ? icons().ICON_EXISTS : icons().ICON_NEXISTS;
         case 5: return battle.ModExists() ? icons().ICON_EXISTS : icons().ICON_NEXISTS;
     }
