@@ -396,9 +396,27 @@ void ChatPanel::OutputLine( const wxString& message, const wxColour& col, const
 
 void ChatPanel::OutputLine( const ChatLine& line )
 {
-  #ifdef __WXMSW__
-    wxWindowUpdateLocker noUpdates(m_chatlog_text);
-  #endif
+  int pos = m_chatlog_text->GetScrollPos(wxVERTICAL);
+  int end = m_chatlog_text->GetScrollRange(wxVERTICAL);
+  int thumb = m_chatlog_text->GetScrollThumb(wxVERTICAL);
+#ifndef __WXMSW__
+  float original_pos = (float)(pos+thumb) / (float)end;
+#else
+  int size = m_chatlog_text->GetSize().GetHeight();
+  float original_pos = (float)(pos+size) / (float)end; // wxmsw is retarded and reports thumb size as 0 always
+#endif
+  if ( original_pos < 0.0f ) original_pos = 0.0f;
+  if ( original_pos > 1.0f ) original_pos = 1.0f; // this is necessary because the code in windows isn't 100% right because thumb always returns 0
+  long original_line = 0;
+#ifndef __WXMSW__
+  if (original_pos < 1.0f )
+  {
+	  original_line = (long)(original_pos *(float)m_chatlog_text->GetNumberOfLines()); // GetNumberOfLines is expensive, only call when necessary
+	  m_chatlog_text->Freeze();
+  }
+#else
+	 wxWindowUpdateLocker noUpdates(m_chatlog_text); // use the automatic one in windows
+#endif
 
   m_chatlog_text->SetDefaultStyle( line.timestyle );
   m_chatlog_text->AppendText( line.time );
@@ -433,13 +451,13 @@ void ChatPanel::OutputLine( const ChatLine& line )
 			{
 				if (m1.Len() > 2 && (m1.GetChar(2) >= 48 && m1.GetChar(2) <= 58))
 				{
-					color = (m1.GetChar(1) - 48)*10+(m1.GetChar(2) - 48);
+					color = (int(m1.GetChar(1)) - 48)*10+(int(m1.GetChar(2)) - 48);
 					_2chars = true;
 					m1 = m1.Mid(3);
 					}
 				else
 				{
-					color = m1.GetChar(1) -48;
+					color = int(m1.GetChar(1)) -48;
 					_2chars = false;
 					m1 = m1.Mid(2);
 					}
@@ -501,12 +519,30 @@ void ChatPanel::OutputLine( const ChatLine& line )
 		int end = 0;
 		for ( int i = 0; i < 20; i++ ) end += m_chatlog_text->GetLineLength( i ) + 1;
 		m_chatlog_text->Remove( 0, end );
-	}
-  #ifdef __WXMSW__
-  m_chatlog_text->ScrollLines( 10 ); // to prevent for weird empty space appended
-  m_chatlog_text->ShowPosition( m_chatlog_text->GetLastPosition() );// scroll to the bottom
-  #endif
+  }
+
+  if (original_pos < 1.0f)
+  {
+#ifndef __WXMSW__
+	  wxString linetext = m_chatlog_text->GetLineText(original_line);
+	  long zoomto = m_chatlog_text->GetValue().Find(linetext);
+	  m_chatlog_text->ShowPosition( zoomto ); // wxgtk is retarded and always autoscrolls
+#endif
+  }
+  else
+  {
+	m_chatlog_text->ScrollLines(10); // wx is retarded, necessary to show the latest line
+#ifdef __WXMSW__
+	m_chatlog_text->ShowPosition( m_chatlog_text->GetLastPosition() );
+#endif
+  }
   this->Refresh();
+#ifndef __WXMSW__
+ if (original_pos < 1.0f)
+  {
+	m_chatlog_text->Thaw();
+  }
+#endif
 }
 
 
@@ -936,6 +972,7 @@ void ChatPanel::Say( const wxString& message )
 		}
 
 		if ( line == _T( "/ver" ) ) {
+			//!this instance is not replaced with GetAppname for sake of help/debug online
 			OutputLine( _( " You have SpringLobby v" ) + GetSpringLobbyVersion(), sett().GetChatColorNormal() , sett().GetChatFont() );
 			return;
 		}
@@ -1074,7 +1111,8 @@ wxString ChatPanel::FindUrl( const long pos ) const
         end++;
 
     wxString ret = m_chatlog_text->GetRange( start, end );
-    if ( ret.StartsWith( _T("http://") ) )
+	//! \todo there's prolly some smarter way to capture a more flexible range of url types
+	if ( ret.StartsWith( _T("http://") ) ||  ret.StartsWith( _T("https://") ) || ret.StartsWith( _T("ftp://") ))
         return ret;
     else
         return _T("");
