@@ -16,8 +16,12 @@
 #include "settings.h"
 
 ChatPanelMenu::ChatPanelMenu(ChatPanel* parent, bool addChanServ, const wxString& /*title */, long /*style*/ )
-    : m_chatpanel(parent),
+	: m_chatpanel(parent),
+	m_user_menu( 0 ),
+	m_menu_all( 0 ),
+	displayjoinitem( 0 ),
     m_autorejoin( 0 ),
+	m_append_menu( 0 ),
     m_withChanserv( addChanServ )
 {}
 
@@ -26,7 +30,7 @@ wxMenu* ChatPanelMenu::GetMenu()
 {
     m_menu_all = new wxMenu();
     CreateNickListMenu();
-    m_append_menu = new wxMenuItem( m_menu_all, CHAT_MENU_DISABLE_APPEND, _( "Disable text appending (workaround for autoscroll)" ), wxEmptyString, wxITEM_CHECK );
+	m_append_menu = new wxMenuItem( m_menu_all, CHAT_MENU_DISABLE_APPEND, _( "Disable text appending" ), wxEmptyString, wxITEM_CHECK );
     m_menu_all->Append( m_append_menu );
     m_append_menu->Check( m_chatpanel->m_disable_append );
 
