@@ -2,24 +2,28 @@
 
 #include "customizations.h"
 #include "springunitsynclib.h"
+#include "images/springlobby.xpm"
 
 #include <wx/image.h>
+#include <wx/msgdlg.h>
+
+const wxString Customizations::IntroKey = wxString ( _T("intro_file") );
 
 /** @brief GetBackground
   *
   * @todo: document this function
   */
-wxBitmap Customizations::GetBackground()
+const wxBitmap& Customizations::GetBackground() const
 {
     return m_background;
 }
 
-wxSize Customizations::GetBackgroundSize()
+wxSize Customizations::GetBackgroundSize() const
 {
     return wxSize( m_background.GetWidth(), m_background.GetHeight() );
 }
 
-const OptionsWrapper& Customizations::GetCustomizations()
+const OptionsWrapper& Customizations::GetCustomizations() const
 {
     return m_customs;
 }
@@ -28,7 +32,7 @@ const OptionsWrapper& Customizations::GetCustomizations()
   *
   * @todo: document this function
   */
-wxIcon Customizations::GetAppIcon()
+const wxIcon& Customizations::GetAppIcon() const
 {
     return m_app_ico;
 }
@@ -37,7 +41,7 @@ wxIcon Customizations::GetAppIcon()
   *
   * @todo: document this function
   */
-wxString Customizations::GetHelpUrl()
+const wxString& Customizations::GetHelpUrl() const
 {
     return m_help_url;
 }
@@ -46,7 +50,7 @@ wxString Customizations::GetHelpUrl()
   *
   * @todo: document this function
   */
-wxString Customizations::GetModname()
+const wxString& Customizations::GetModname() const
 {
     return m_modname;
 }
@@ -73,6 +77,7 @@ bool Customizations::Init(const wxString& modname)
 
         m_help_url = m_customs.getSingleValue( _T("help_url") );
     }
+	m_active =  ret;
     return ret;
 }
 
@@ -81,10 +86,35 @@ bool Customizations::Init(const wxString& modname)
   * @todo: document this function
   */
  Customizations::Customizations()
+	 : m_app_ico(springlobby_xpm),
+	 m_active( false )
 {
 
 }
 
+bool Customizations::Active() const
+{
+	return m_active;
+}
+
+bool Customizations::KeyExists( const wxString& key ) const
+{
+	OptionType dummy;
+	return m_customs.keyExists( key, OptionsWrapper::ModCustomizations, false, dummy );
+}
+
+bool Customizations::Provides( const wxString& key ) const
+{
+	return m_active && KeyExists( key );
+}
+
+wxString Customizations::GetIntroText() const
+{
+	if ( !m_active )
+		return wxEmptyString;
+	return usync().GetTextfileAsString( m_modname, m_customs.getSingleValue( IntroKey ) );
+}
+
 /** @brief SLcustomizations
   *
   * @todo: document this function
