@@ -52,7 +52,7 @@ class PlaybackListCtrl : public CustomVirtListCtrl< const PlaybackImp*, Playback
     void OnDLMod( wxCommandEvent& event );
     void OnColClick( wxListEvent& event );
 
-    virtual void SetTipWindowText( const long item_hit, const wxPoint position);
+    virtual void SetTipWindowText( const long item_hit, const wxPoint& position);
 
     virtual void HighlightItem( long /*unused*/ ){};
 
