@@ -14,7 +14,7 @@ class Battle;
 class ServerEvents : public IServerEvents, public wxEvtHandler
 {
   public:
-    ServerEvents( Server& serv) : m_serv(serv) {}
+    ServerEvents( Server& serv) : m_serv(serv), m_autolaunch(false), m_autoclose(false) {}
     ~ServerEvents() {}
 
   // Uicontrol interface
@@ -86,6 +86,7 @@ class ServerEvents : public IServerEvents, public wxEvtHandler
     void OnRing( const wxString& from );
 
     void OnServerMessage( const wxString& message );
+	void OnServerBroadcast( const wxString& message );
     void OnServerMessageBox( const wxString& message );
     void OnChannelMessage( const wxString& channel, const wxString& msg );
 
