@@ -18,6 +18,7 @@
 //#include <wx/txtstrm.h>
 //#include <wx/wfstream.h>
 #include <wx/textfile.h>
+#include <wx/sstream.h>
 #include <cmath>
 #include <stdexcept>
 #include <clocale>
@@ -91,10 +92,14 @@ void SpringUnitSync::PopulateArchiveList()
 {
   m_maps_list.clear();
   m_mods_list.clear();
-  m_mod_array.Empty();
-  m_map_array.Empty();
+  m_mod_array.Clear();
+  m_map_array.Clear();
+  m_unsorted_mod_array.Clear();
+  m_unsorted_map_array.Clear();
   m_map_image_cache.Clear();
   m_mapinfo_cache.Clear();
+  m_maps_unchained_hash.clear();
+  m_mods_unchained_hash.clear();
 
   int numMaps = susynclib().GetMapCount();
   for ( int i = 0; i < numMaps; i++ )
@@ -1231,6 +1236,24 @@ void SpringUnitSync::GetMapExAsync( const wxString& mapname, int evtHandlerId )
   m_cache_thread.DoWork( work, 200 /* higher prio then GetMinimapAsync */ );
 }
 
+wxString SpringUnitSync::GetTextfileAsString( const wxString& modname, const wxString& file_path )
+{
+	susynclib().SetCurrentMod( modname );
+
+	int ini = susynclib().OpenFileVFS ( file_path );
+	if ( !ini )
+		return wxEmptyString;
+
+	int FileSize = susynclib().FileSizeVFS(ini);
+	if (FileSize == 0) {
+		susynclib().CloseFileVFS(ini);
+		return wxEmptyString;
+	}
+
+	uninitialized_array<char> FileContent(FileSize);
+	susynclib().ReadFileVFS(ini, FileContent, FileSize);
+	return wxString( FileContent, wxConvAuto(), size_t( FileSize ) );
+}
 
 ////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////// EvtHandlerCollection code
