@@ -309,9 +309,18 @@ bool TASServer::ExecuteSayCommand( const wxString& cmd )
     }
     else if ( subcmd == _T("/changepassword") )
     {
-				if ( arrayparams.GetCount() != 3 ) return false;
-        wxString oldpassword = GetPasswordHash( arrayparams[1] );
-        wxString newpassword = GetPasswordHash( arrayparams[2] );
+		if ( arrayparams.GetCount() < 2 ) return false;
+		wxString oldpassword = sett().GetServerAccountPass( GetServerName() );
+		wxString newpassword;
+		if  ( oldpassword.IsEmpty() || !sett().GetServerAccountSavePass(GetServerName()) )
+		{
+			oldpassword = GetPasswordHash(arrayparams[1]);
+			newpassword = GetPasswordHash( arrayparams[2] );
+		}
+		else
+		{
+			newpassword = GetPasswordHash( params );
+		}
         SendCmd( _T("CHANGEPASSWORD"), oldpassword + _T(" ") + newpassword );
         return true;
     }
@@ -680,7 +689,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
                               haspass, rank, hash, map, title, mod );
         if ( nick == m_relay_host_bot )
         {
-           GetBattle( id ).SetIsProxy( true );
+		   GetBattle( id ).SetProxy( m_relay_host_bot );
            JoinBattle( id, sett().GetLastHostPassword() ); // autojoin relayed host battles
         }
     }
@@ -807,6 +816,28 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
     else if ( cmd == _T("SAIDPRIVATE") )
     {
         nick = GetWordParam( params );
+		if ( nick == m_relay_host_bot )
+		{
+			if ( params.StartsWith(_T("JOINEDBATTLE")) )
+			{
+				GetWordParam( params ); // skip first word, it's the message itself
+				id = GetIntParam( params );
+				wxString usernick = GetWordParam( params );
+				wxString userScriptPassword = GetWordParam( params );
+				try
+				{
+					User& usr = GetUser(usernick);
+					usr.BattleStatus().scriptPassword = userScriptPassword;
+					Battle* battle = GetCurrentBattle();
+					if (battle)
+					{
+						if ( battle->CheckBan( usr ) ) return;
+					}
+					SetRelayIngamePassword( usr );
+				} catch (...) {}
+				return;
+			}
+		}
         if ( nick == m_relay_host_manager )
         {
           if ( params.StartsWith( _T("\001") ) ) // error code
@@ -838,6 +869,10 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
         m_battle_id = id;
 		m_se->OnJoinedBattle( id, hash );
         m_se->OnBattleInfoUpdated( m_battle_id );
+		try
+		{
+		 if (GetBattle(id).IsProxy()) RelayCmd(_T("SUPPORTSCRIPTPASSWORD")); // send flag to relayhost marking we support script passwords
+		} catch(...) {}
     }
     else if ( cmd == _T("CLIENTBATTLESTATUS") )
     {
@@ -942,9 +977,12 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
         }
         if( usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) )
         {
-					 bstatus.aiversion = ai.AfterLast( _T('|') );
-					 ai = ai.BeforeLast( _T('|') );
-        	 bstatus.aishortname = ai;
+			if (ai.Find(_T('|')) != -1)
+			{
+				bstatus.aiversion = ai.AfterLast( _T('|') );
+				ai = ai.BeforeLast( _T('|') );
+			}
+			bstatus.aishortname = ai;
         }
         else
         {
@@ -1082,7 +1120,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
     }
     else if ( cmd == _T("BROADCAST"))
     {
-        m_se->OnServerMessage( params );
+		m_se->OnServerBroadcast( params );
     }
     else if ( cmd == _T("SERVERMSGBOX"))
     {
@@ -1107,7 +1145,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
     else if ( cmd == _T("MUTELIST") )
     {
         wxString mutee = GetWordParam( params );
-        wxString description = GetWordParam( params );
+		wxString description = GetSentenceParam( params );
         m_se->OnMutelistItem( m_current_chan_name_mutelist, mutee, description );
     }
     else if ( cmd == _T("MUTELISTEND") )
@@ -1173,6 +1211,16 @@ void TASServer::SendCmd( const wxString& command, const wxString& param )
 		}
 }
 
+void TASServer::SetRelayIngamePassword( const User& user )
+{
+	Battle* battle = GetCurrentBattle();
+	if (battle)
+	{
+		if ( !battle->GetInGame() ) return;
+	}
+	RelayCmd( _T("SETINGAMEPASSWORD"), user.GetNick() + _T(" ") + user.BattleStatus().scriptPassword );
+}
+
 void TASServer::Ping()
 {
 	SendCmd( _T("PING") );
@@ -1420,7 +1468,7 @@ void TASServer::HostBattle( BattleOptions bo, const wxString& password )
     cmd += bo.modname;
 
     m_delayed_open_command = _T("");
-    if ( !bo.isproxy )
+	if ( !bo.userelayhost )
     {
        SendCmd( _T("OPENBATTLE"), cmd );
     }
@@ -1428,7 +1476,7 @@ void TASServer::HostBattle( BattleOptions bo, const wxString& password )
     {
        if ( bo.relayhost.IsEmpty() )
        {
-					 wxArrayString relaylist = GetRelayHostList();
+			wxArrayString relaylist = GetRelayHostList();
            unsigned int numbots = relaylist.GetCount();
            if ( numbots > 0 )
            {
@@ -1567,21 +1615,41 @@ void TASServer::SendHostInfo( HostInfo update )
         OptionsWrapper::wxStringTripleVec optlistMap = battle.CustomBattleOptions().getOptions( OptionsWrapper::MapOption );
         for (OptionsWrapper::wxStringTripleVec::iterator it = optlistMap.begin(); it != optlistMap.end(); ++it)
         {
-            cmd << _T("game/mapoptions/") << it->first + _T("=") << it->second.second << _T("\t");
+			wxString newcmd = _T("game/mapoptions/") + it->first + _T("=") + it->second.second + _T("\t");
+			if ( cmd.size() + newcmd.size() > 900 ) // should be 1024 add margin for relayhost name and command itself
+			{
+				if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
+				else RelayCmd( _T("SETSCRIPTTAGS"), cmd );
+				cmd = _T("");
+			}
+			cmd << newcmd;
         }
         OptionsWrapper::wxStringTripleVec optlistMod = battle.CustomBattleOptions().getOptions( OptionsWrapper::ModOption );
         for (OptionsWrapper::wxStringTripleVec::iterator it = optlistMod.begin(); it != optlistMod.end(); ++it)
         {
-            cmd << _T("game/modoptions/") << it->first << _T("=") << it->second.second << _T("\t");
+			wxString newcmd = _T("game/modoptions/") + it->first + _T("=") + it->second.second + _T("\t");
+			if ( cmd.size() + newcmd.size() > 900 )// should be 1024 add margin for relayhost name and command itself
+			{
+				if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
+				else RelayCmd( _T("SETSCRIPTTAGS"), cmd );
+				cmd = _T("");
+			}
+			cmd << newcmd;
         }
         OptionsWrapper::wxStringTripleVec optlistEng = battle.CustomBattleOptions().getOptions( OptionsWrapper::EngineOption );
         for (OptionsWrapper::wxStringTripleVec::iterator it = optlistEng.begin(); it != optlistEng.end(); ++it)
         {
-            cmd << _T("game/") << it->first << _T("=") << it->second.second << _T("\t");
+			wxString newcmd = _T("game/") + it->first + _T("=") + it->second.second + _T("\t");
+			if ( cmd.size() + newcmd.size() > 900 )// should be 1024 add margin for relayhost name and command itself
+			{
+				if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
+				else RelayCmd( _T("SETSCRIPTTAGS"), cmd );
+				cmd = _T("");
+			}
+			cmd << newcmd;
         }
-
-        if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
-        else RelayCmd( _T("SETSCRIPTTAGS"), cmd );
+		if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
+		else RelayCmd( _T("SETSCRIPTTAGS"), cmd );
     }
 
     if ( (update & IBattle::HI_StartRects) > 0 )   // Startrects should be updated.
@@ -2038,7 +2106,12 @@ void TASServer::BattleKickPlayer( int battleid, User& user )
     }
 
     //KICKFROMBATTLE username
-    if( !GetBattle(battleid).IsProxy() ) SendCmd( _T("KICKFROMBATTLE"), user.GetNick() );
+	if( !GetBattle(battleid).IsProxy() )
+	{
+		user.BattleStatus().scriptPassword = wxString::Format(_T("%04x%04x"), rand()&0xFFFF, rand()&0xFFFF); // reset his password to something random, so he can't rejoin
+		SetRelayIngamePassword( user );
+		SendCmd( _T("KICKFROMBATTLE"), user.GetNick() );
+	}
     else RelayCmd( _T("KICKFROMBATTLE"), user.GetNick() );
 }
 
