@@ -55,6 +55,7 @@
     #include <wx/stdpaths.h>
 #endif
 
+#include "reconnectdialog.h"
 #include "utils/customdialogs.h"
 #include "utils/platform.h"
 #include "updater/versionchecker.h"
@@ -109,9 +110,11 @@ Ui::Ui() :
         m_serv(0),
         m_main_win(0),
         m_con_win(0),
+		m_reconnect_dialog(0),
         m_upd_counter_torrent(0),
         m_first_update_trigger(true),
 		m_ingame(false),
+		m_recconecting_wait(false),
 		m_battle_info_updatedSink( this, &BattleEvents::GetBattleEventSender( ( BattleEvents::BattleInfoUpdate ) ) )
 {
     m_main_win = new MainWindow( );
@@ -123,7 +126,6 @@ Ui::Ui() :
 Ui::~Ui()
 {
     Disconnect();
-
     delete m_serv;
 }
 
@@ -160,14 +162,16 @@ void Ui::ShowMainWindow()
 //! @note It will create the ConnectWindow if not allready created
 void Ui::ShowConnectWindow()
 {
-    if ( m_con_win == 0 )
+	if ( IsConnecting() || IsConnected() || m_recconecting_wait )
+		return;
+	if ( m_con_win == 0 )
     {
         ASSERT_LOGIC( m_main_win != 0, _T("m_main_win = 0") );
         m_con_win = new ConnectWindow( m_main_win, *this );
     }
-    m_con_win->CenterOnParent();
-    m_con_win->Show(true);
-    m_con_win->Raise();
+	m_con_win->CenterOnParent();
+	m_con_win->Show(true);
+	m_con_win->Raise();
 }
 
 
@@ -177,14 +181,14 @@ void Ui::ShowConnectWindow()
 //! @see DoConnect
 void Ui::Connect()
 {
-    bool doit = sett().GetAutoConnect();
-    if ( !doit )
+	wxString server_name = sett().GetDefaultServer();
+	wxString nick = sett().GetServerAccountNick( server_name );
+	bool autoconnect = sett().GetAutoConnect();
+	if ( !autoconnect || server_name.IsEmpty() || nick.IsEmpty() )
         ShowConnectWindow();
     else
     {
         m_con_win = 0;
-        wxString server_name = sett().GetDefaultServer();
-        wxString nick = sett().GetServerAccountNick( server_name );
         wxString pass = sett().GetServerAccountPass( server_name );
         DoConnect( server_name, nick, pass);
     }
@@ -198,9 +202,7 @@ void Ui::Reconnect()
     wxString pass  = sett().GetServerAccountPass(servname);
     if ( !sett().GetServerAccountSavePass(servname) )
     {
-        wxString pass2 = pass;
-        if ( !AskPassword( _("Server password"), _("Password"), pass2 ) ) return;
-        pass = pass2;
+		if ( !AskPassword( _("Server password"), _("Password"), pass ) ) return;
     }
 
     Disconnect();
@@ -223,13 +225,24 @@ void Ui::Disconnect()
 void Ui::DoConnect( const wxString& servername, const wxString& username, const wxString& password )
 {
 	if ( m_reconnect_delay_timer.IsRunning() ) {
+		m_recconecting_wait = true;
 		AutocloseMessageBox m( &mw(), _("Waiting for reconnect"), wxMessageBoxCaptionStr, s_reconnect_delay_ms );
 		m.ShowModal();
+		m_recconecting_wait = false;
 	}
 
     wxString host;
     int port;
 
+	if ( servername != m_last_used_backup_server ) // do not save the server as default if it's a backup one
+	{
+		sett().SetDefaultServer( servername );
+	}
+	else
+	{
+		m_last_used_backup_server = _T("");
+	}
+
     if ( !sett().ServerExists( servername ) )
     {
         ASSERT_LOGIC( false, _T("Server does not exist in settings") );
@@ -255,7 +268,7 @@ void Ui::DoConnect( const wxString& servername, const wxString& username, const
     host = sett().GetServerHost( servername );
     port = sett().GetServerPort( servername );
 
-	serverSelector().GetServer().uidata.panel = m_main_win->GetChatTab().AddChatPanel( *m_serv, servername );
+	AddServerWindow( servername );
 	serverSelector().GetServer().uidata.panel->StatusMessage( _T("Connecting to server ") + servername + _T("...") );
 
     // Connect
@@ -263,6 +276,29 @@ void Ui::DoConnect( const wxString& servername, const wxString& username, const
 
 }
 
+void Ui::AddServerWindow( const wxString& servername )
+{
+	if ( !serverSelector().GetServer().uidata.panel )
+	{
+		serverSelector().GetServer().uidata.panel = m_main_win->GetChatTab().AddChatPanel( *m_serv, servername );
+
+	}
+}
+
+
+void Ui::ReopenServerTab()
+{
+	if ( serverSelector().GetServer().IsOnline() )
+	{
+		AddServerWindow( serverSelector().GetServer().GetServerName() );
+		// re-add all users to the user list
+		const UserList& list = serverSelector().GetServer().GetUserList();
+		for ( unsigned int i = 0; i < list.GetNumUsers(); i++ )
+		{
+			serverSelector().GetServer().uidata.panel->OnChannelJoin( list.GetUser(i) );
+		}
+	}
+}
 
 bool Ui::DoRegister( const wxString& servername, const wxString& username, const wxString& password,wxString& reason)
 {
@@ -292,6 +328,11 @@ bool Ui::DoRegister( const wxString& servername, const wxString& username, const
 
 }
 
+bool Ui::IsConnecting() const
+{
+	if ( m_reconnect_dialog != 0 ) return m_reconnect_dialog->IsShown();
+	return false;
+}
 
 bool Ui::IsConnected() const
 {
@@ -355,7 +396,7 @@ void Ui::DownloadFileWebsite( const wxString& name )
 {
 	wxString newname = name;
 	newname.Replace( _T(" "), _T("+") );
-	wxString url = _T(" http://spring.jobjol.nl/search_result.php?search_cat=1&select_select=select_file_subject&Submit=Search&search=") + newname;
+	wxString url = _T("http://spring.jobjol.nl/search_result.php?search_cat=1&select_select=select_file_subject&Submit=Search&search=") + newname;
 	OpenWebBrowser ( url );
 }
 
@@ -463,7 +504,7 @@ void Ui::ConsoleHelp( const wxString& topic )
     }
     if ( topic == wxEmptyString )
     {
-        panel->ClientMessage( _("SpringLobby commands help.") );
+		panel->ClientMessage( IdentityString( _("%s commands help.") ) );
         panel->ClientMessage( _T("") );
         panel->ClientMessage( _("Global commands:") );
         panel->ClientMessage( _("  \"/away\" - Sets your status to away.") );
@@ -478,9 +519,9 @@ void Ui::ConsoleHelp( const wxString& topic )
         panel->ClientMessage( _("  \"/part\" - Leaves current channel.") );
         panel->ClientMessage( _("  \"/p\" - Alias to /part.") );
         panel->ClientMessage( _("  \"/rename newalias\" - Changes your nickname to newalias.") );
-        panel->ClientMessage( _("  \"/sayver\" - Says what version of springlobby you have in chat.") );
+		panel->ClientMessage( IdentityString( _("  \"/sayver\" - Says what version of %s you have in chat.") ) );
         panel->ClientMessage( _("  \"/testmd5 text\" - Returns md5-b64 hash of given text.") );
-        panel->ClientMessage( _("  \"/ver\" - Displays what version of SpringLobby you have.") );
+		panel->ClientMessage( IdentityString( _("  \"/ver\" - Displays what version of %s you have.") ) );
         panel->ClientMessage( _("  \"/clear\" - Clears all text from current chat panel") );
         panel->ClientMessage( _T("") );
         panel->ClientMessage( _("Chat commands:") );
@@ -551,23 +592,21 @@ void Ui::OnUpdate( int mselapsed )
 void Ui::OnConnected( Server& server, const wxString& server_name, const wxString& /*unused*/, bool /*supported*/ )
 {
     wxLogDebugFunc( _T("") );
-    if ( !m_last_used_backup_server.IsEmpty() )
-    {
-    	 m_last_used_backup_server = _T("");
-    }
-    else // connect successful & it's not a backup server fallback -> save as default
-    {
-			 sett().SetDefaultServer( server_name );
-    }
     if ( !IsSpringCompatible() )
     {
     	#ifdef __WXMSW__
-    	if ( Ask( _T("Request update"), _T("Would you like to query the server for a spring update?\n The server is totally demential and will disconnect you if no automatic update will be available") ) ) server.RequestSpringUpdate();
+			server.RequestSpringUpdate();
     	#endif
     }
 
     if ( server.uidata.panel ) server.uidata.panel->StatusMessage( _T("Connected to ") + server_name + _T(".") );
 		mw().GetBattleListTab().OnConnected();
+
+	delete m_con_win;
+	m_con_win = 0;
+
+	delete m_reconnect_dialog;
+	m_reconnect_dialog = 0;
 }
 
 
@@ -655,10 +694,22 @@ void Ui::OnDisconnected( Server& server, bool wasonline )
 
 void Ui::ConnectionFailurePrompt()
 {
-	static wxMessageDialog dlg( &mw(), _("A connection couldn't be established with the server\nWould you like to try again with the same server?\nNo to switch to next server in the list"), _("Connection failure"), wxYES_NO | wxCANCEL | wxNO_DEFAULT );
-	if ( dlg.IsShown() )
+	if ( m_reconnect_dialog != 0 )
+	{
 		return;
-	switch ( dlg.ShowModal() )
+	}
+	if ( m_recconecting_wait )
+	{
+		return;
+	}
+	// if connect window instance exists, delete it to avoid 2 windows which do the same task
+	delete m_con_win;
+	m_con_win = 0;
+	m_reconnect_dialog = new ReconnectDialog();
+	int returnval = m_reconnect_dialog->ShowModal();
+	delete m_reconnect_dialog;
+	m_reconnect_dialog = 0;
+	switch ( returnval )
 	{
 		case wxID_YES: // try again with the same server/settings
 		{
@@ -667,8 +718,11 @@ void Ui::ConnectionFailurePrompt()
 		}
 		case wxID_NO: // switch to next server in the list
 		{
-			SwitchToNextServer();
-			ShowConnectWindow();
+			wxString m_last_used_backup_server = GetNextServer();
+			wxString current_server = sett().GetDefaultServer();
+			sett().SetDefaultServer( m_last_used_backup_server );// temp set backup server as default
+			Connect();
+			sett().SetDefaultServer( current_server ); // restore original serv
 			break;
 		}
 		default:
@@ -679,7 +733,9 @@ void Ui::ConnectionFailurePrompt()
 	}
 }
 
-void Ui::SwitchToNextServer()
+
+
+wxString Ui::GetNextServer()
 {
 		wxString previous_server = m_last_used_backup_server;
 		if ( previous_server.IsEmpty() ) previous_server = sett().GetDefaultServer();
@@ -687,11 +743,7 @@ void Ui::SwitchToNextServer()
 		int position = serverlist.Index( previous_server );
 		if ( position == wxNOT_FOUND ) position = -1;
 		position = ( position + 1) % serverlist.GetCount(); // switch to next in the list
-		m_last_used_backup_server = serverlist[position];
-		sett().SetDefaultServer( m_last_used_backup_server );
-		if ( m_con_win ) // we don't necessarily have that constructed yet (autojoin)
-            m_con_win->ReloadServerList();
-		sett().SetDefaultServer( previous_server ); // don't save the new server as default when switched this way
+		return serverlist[position];
 }
 
 static inline bool IsAutoJoinChannel( Channel& chan )
@@ -890,14 +942,39 @@ void Ui::OnMotd( Server& server, const wxString& message )
     if ( server.uidata.panel != 0 ) server.uidata.panel->Motd( message );
 }
 
+void Ui::OnServerBroadcast( Server& /*server*/, const wxString& message )
+{
+	if ( m_main_win == 0 ) return;
+	mw().GetChatTab().BroadcastMessage( message );
+	try // send it to battleroom too
+	{
+		mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().StatusMessage(message);
+	}
+	catch(...) {}
+}
+
 
 void Ui::OnServerMessage( Server& server, const wxString& message )
 {
-    if ( server.uidata.panel != 0 ) server.uidata.panel->StatusMessage( message );
-    else
-    {
-        ShowMessage( _("Server message"), message );
-    }
+	if ( !sett().GetBroadcastEverywhere() )
+	{
+		if ( server.uidata.panel != 0 ) server.uidata.panel->StatusMessage( message );
+	}
+	else
+	{
+		if ( server.uidata.panel != 0 ) server.uidata.panel->StatusMessage( message );
+		if ( m_main_win == 0 ) return;
+		ChatPanel* activepanel = mw().GetChatTab().GetActiveChatPanel();
+		if ( activepanel != 0 )
+		{
+			if (activepanel != server.uidata.panel) activepanel->StatusMessage(message); // don't send it twice to the server tab
+		}
+		try // send it to battleroom too
+		{
+			mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().StatusMessage(message);
+		}
+		catch(...) {}
+	}
 }
 
 
@@ -1138,7 +1215,7 @@ void Ui::OnSpringTerminated( long exit_code )
         }
     } catch ( assert_exception ){}
 
-	if ( sett().GetReportStats() && exit_code ) {
+	if ( false && exit_code ) { // disabled for now for stability
 		#if wxUSE_DEBUGREPORT && defined(ENABLE_DEBUG_REPORT)
 			SpringDebugReport report;
 			if ( wxDebugReportPreviewStd().Show( report ) )
@@ -1258,8 +1335,11 @@ void Ui::FirstRunWelcome()
 #endif
 
         wxLogMessage( _T("first time startup"));
-		wxMessageBox(_("Hi ") + wxGetUserName() + _(",\nIt looks like this is your first time using SpringLobby. I have guessed a configuration that I think will work for you but you should review it, especially the Spring configuration."), _("Welcome"),
-                     wxOK | wxICON_INFORMATION, &mw() );
+		wxMessageBox( wxString::Format( _("Hi %s,\nIt looks like this is your first time using %s. I have guessed a configuration that I think will work for you but you should review it, especially the Spring configuration."),
+										wxGetUserName().c_str(),
+										GetAppName().c_str() ),
+					  _("Welcome"),
+					  wxOK | wxICON_INFORMATION, &mw() );
 
 		IntroGuide* intro = new IntroGuide();
 		intro->Show();
@@ -1295,9 +1375,6 @@ void Ui::FirstRunWelcome()
 
 void Ui::CheckForUpdates()
 {
-	wxString t = _T("SpringLobby test\njfrepojeivnpenver\nwvpreivienrio\npwoewnpfwpnef\njcwoejfwp");
-	Paste2Pastebin( t );
-	return;
     wxString latestVersion = GetLatestVersion();
 
     if (latestVersion == _T("-1"))
@@ -1312,7 +1389,11 @@ void Ui::CheckForUpdates()
     if ( !latestVersion.IsSameAs(myVersion, false) )
     {
         #ifdef __WXMSW__
-        int answer = customMessageBox(SL_MAIN_ICON, _("Your SpringLobby version is not up to date.\n\n") + msg + _("\n\nWould you like for me to autodownload the new version? Changes will take effect next you launch the lobby again."), _("Not up to date"), wxYES_NO);
+		int answer = customMessageBox(SL_MAIN_ICON,
+									  wxString::Format( _("Your %s version is not up to date.\n\n%s\n\nWould you like for me to autodownload the new version? Changes will take effect next you launch the lobby again."),
+														GetAppName().c_str(),
+														msg.c_str() ),
+									  _("Not up to date"), wxYES_NO);
         if (answer == wxYES)
         {
             wxString command = _T("\"") + wxPathOnly( wxStandardPaths::Get().GetExecutablePath() ) + wxFileName::GetPathSeparator() + _T("springlobby_updater.exe\"");
