@@ -51,15 +51,15 @@ double LevenshteinDistance(wxString s, wxString t);
  */
 wxString GetBestMatch(const wxArrayString& a, const wxString& s, double* distance = 0 );
 
-#if defined(ENABLE_DEBUG_REPORT)
-    wxString Paste2Pastebin( const wxString& message );
-#endif
+
+wxString Paste2Pastebin( const wxString& message );
+
 
 #endif // SPRINGLOBBY_HEADERGUARD_MISC_H
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
