@@ -9,6 +9,7 @@
 #include <wx/textfile.h>
 #include <wx/filename.h>
 #include <wx/dir.h>
+#include <wx/app.h>
 
 #ifdef __WXMSW__
  #include <wx/msw/registry.h>
@@ -17,6 +18,8 @@
 
 #include <iostream>
 
+#include <stdio.h>
+
 #include "conversion.h"
 #include "../updater/versionchecker.h"
 #include "customdialogs.h"
@@ -31,7 +34,7 @@ wxString GetLibExtension()
 
 //! @brief Initializes the logging functions.
 ///initializes logging in an hidden stream and std::cout/gui messages
-wxLogWindow* InitializeLoggingTargets( wxFrame* parent, bool console, bool showgui, bool /*logcrash*/, int verbosity, wxLogChain* logChain )
+wxLogWindow* InitializeLoggingTargets( wxFrame* parent, bool console, const wxString&  logfilepath, bool showgui, bool /*logcrash*/, int verbosity, wxLogChain* logChain )
 {
     wxLogWindow* loggerwin = 0;
 
@@ -41,12 +44,24 @@ wxLogWindow* InitializeLoggingTargets( wxFrame* parent, bool console, bool showg
         ///std::cout logging
         logChain = new wxLogChain( new wxLogStream( &std::cout ) );
     }
+#else
+	if (  console && verbosity != 0 )
+	{
+		///std::cerr logging
+		logChain = new wxLogChain( new  wxLogStderr( 0 ) );
+	}
 #endif
 
+	if ( logfilepath.size() != 0 && verbosity != 0 )
+	{
+		FILE* logfile = fopen(C_STRING(logfilepath), "w"); // even if it returns null, wxLogStderr will switch to stderr logging, so it's fine
+		logChain = new wxLogChain( new  wxLogStderr( logfile ) );
+	}
+
     if ( showgui && verbosity != 0 )
     {
         ///gui window logging
-        loggerwin = new wxLogWindow( (wxWindow*) parent, _T("SpringLobby error console"), showgui );
+		loggerwin = new wxLogWindow( (wxWindow*) parent, IdentityString( _("%s error console") ), showgui );
         logChain = new wxLogChain( loggerwin );
     }
 
@@ -356,3 +371,16 @@ CwdGuard::~CwdGuard()
 {
     wxSetWorkingDirectory( m_old_cwd );
 }
+
+wxString GetAppName( const bool lowerCase )
+{
+	wxString name = wxTheApp->GetAppName();
+	if ( lowerCase )
+		name.MakeLower();
+	return name;
+}
+
+wxString IdentityString(const wxString format, bool lowerCase )
+{
+	return wxString::Format( format, GetAppName( lowerCase ).c_str() );
+}
